@@ -4,6 +4,9 @@ from fluid.editor import (
 from fluid.env import (
     setup_environment,
 )
+from fluid.stack import (
+    setup_stack,
+)
 from fluid.utils import (
     load_config,
 )
@@ -12,5 +15,6 @@ from fluid.utils import (
 def main() -> None:
     config = load_config()
     print(config)
-    # setup_vscode(config["code"])
-    # setup_environment(config["environment"])
+    setup_environment(config["environment"])
+    setup_vscode(config["code"])
+    setup_stack(config["stack"])
